searchNodes=[{"doc":"Pack Elixir data into self-extracting archives to paste elsewhere. Ever had a large data structure you needed to attach to a ticket to make troubleshooting easier? Worse, was it full of references, pids, and structures with custom Inspect protocol installations that made the output of IO.inspect/2 not valid Elixir? Smuggle makes it easy to pipe that value to a self-extracting archive you can paste anywhere for someone else to try on their system. It&#39;s as easy as: Smuggle.dump(value) The output will be Elixir code to reproduce your value on another system. It&#39;ll be: Portable because :erlang.term_to_binary/2 Short because compressed: 9 Easy to get through anything that carries text because Base.encode64/1 and line breaks (fn v -&gt; v |&gt; Base.decode64!(ignore: :whitespace) |&gt; :erlang.binary_to_term() end).(~S&quot;&quot;&quot; g20AAABBT2gsIGdvb2Qgb24geW91IGZvciBjaGVja2luZy4gSXQgY291bGQgaGF2ZSBiZWVuIGFu eXRoaW5nLCByaWdodD8= &quot;&quot;&quot;) See Usage below for more details. Do you need to take a dependency on this? The first few dozen times I did it, I copied or re-invented the encode/1 and decode/1 pipelines, but I&#39;m enjoying having it around now. If you&#39;re in a hurry and don&#39;t want to touch mix, loot what you need from below: def encode(term) do term |&gt; :erlang.term_to_binary(compressed: 9) |&gt; Base.encode64() |&gt; Stream.unfold(&amp;String.split_at(&amp;1, 76)) |&gt; Enum.take_while(&amp;(&amp;1 != &quot;&quot;)) |&gt; Enum.join(&quot;\\n&quot;) end def decode(encoded) do encoded |&gt; Base.decode64!(ignore: :whitespace) |&gt; :erlang.binary_to_term() end Usage If your target is an iex prompt: Smuggle.dump(value) # copy # paste into other iex The output of Smuggle.dump(true) is: (fn v -&gt; v |&gt; Base.decode64!(ignore: :whitespace) |&gt; :erlang.binary_to_term() end).(~S&quot;&quot;&quot; g2QABHRydWU= &quot;&quot;&quot;) Paste that back into the iex prompt of a local or remote console, and you&#39;ll get the value back: Erlang/OTP 23 [erts-11.0.3] [source] [64-bit] [smp:16:16] [ds:16:16:10] [async-threads:1] [hipe] Interactive Elixir (1.10.4) - press Ctrl+C to exit (type h() ENTER for help) iex(1)&gt; (fn v -&gt; v |&gt; Base.decode64!(ignore: :whitespace) |&gt; :erlang.binary_to_term() end).(~S&quot;&quot;&quot; ...(1)&gt; g2QABHRydWU= ...(1)&gt; &quot;&quot;&quot;) true It&#39;s more impressive when it&#39;s an %Ecto.Changeset{}, but you get the gist. Speaking of which, sometimes you&#39;re trying to paste vital troubleshooting information into a GitHub issue, comment, or gist. It&#39;s polite to wrap that in a &lt;details&gt;, and Smuggle does all the hard work: Smuggle.dump(value, wrapper: :gfm) # copy # paste into GitHub On GitHub, the self-extracting archive will be hidden behind a friendly summary so it&#39;s easy to skip: That friendly open source maintainer who&#39;ll check it out, though, can click once to see the whole thing:","ref":"Smuggle.html","title":"Smuggle","type":"module"},{"doc":"Decode a compressed binary in Base64.","ref":"Smuggle.html#decode/1","title":"Smuggle.decode/1","type":"function"},{"doc":"Dump self-extracted.","ref":"Smuggle.html#dump/2","title":"Smuggle.dump/2","type":"function"},{"doc":"Encode a term to a compressed binary in Base64.","ref":"Smuggle.html#encode/1","title":"Smuggle.encode/1","type":"function"},{"doc":"Generate self-extraction code.","ref":"Smuggle.html#gen_sfx/1","title":"Smuggle.gen_sfx/1","type":"function"},{"doc":"Wrap in a details tag for GitHub-flavoured markdown.","ref":"Smuggle.html#gfm/1","title":"Smuggle.gfm/1","type":"function"},{"doc":"No-op wrapper.","ref":"Smuggle.html#noop/1","title":"Smuggle.noop/1","type":"function"},{"doc":"Encoded terms.","ref":"Smuggle.html#t:encoded/0","title":"Smuggle.encoded/0","type":"type"},{"doc":"Self-extraction code.","ref":"Smuggle.html#t:sfx/0","title":"Smuggle.sfx/0","type":"type"}]